@@ -1,13 +1,13 @@
 """
-PyAEZ
-Written by N. Lakmal Deshapriya
+PyAEZ: Biomass Calculation
+2020: N. Lakmal Deshapriya
 """
 
 import numpy as np
 import csv
 
-from . import ALL_REDUCTION_FACTORS_IRR as crop_P_IRR
-from . import ALL_REDUCTION_FACTORS_RAIN as crop_P_RAIN
+import ALL_REDUCTION_FACTORS_IRR as crop_P_IRR
+import ALL_REDUCTION_FACTORS_RAIN as crop_P_RAIN
 
 class SoilConstraints(object):
 
