@@ -1,12 +1,12 @@
 """
 PyAEZ
-Written by N. Lakmal Deshapriya
+2020: N. Lakmal Deshapriya
 """
 
 import numpy as np
 
-from  . import ALL_REDUCTION_FACTORS_IRR as crop_P_IRR
-from  . import ALL_REDUCTION_FACTORS_RAIN as crop_P_RAIN
+import ALL_REDUCTION_FACTORS_IRR as crop_P_IRR
+import ALL_REDUCTION_FACTORS_RAIN as crop_P_RAIN
 
 class TerrainConstraints(object):
 
